@@ -11,7 +11,7 @@ from colors import *
 import pyfiglet
 import gitlab
 import yaml
-
+import os
 
 class facile_trigger_helper(object):
     """
@@ -62,7 +62,8 @@ class facile_trigger_helper(object):
                     robot_path = path               
 
             return robot_path
-    
+
+
     def main(self, args: List[str]):
        
         """
@@ -70,7 +71,7 @@ class facile_trigger_helper(object):
         :project_id variable aims gitlab id found on project >> General:
         """
         # Require parameters
-        term = Terminal()
+
         args = self.convert_args(args)
         assert args.gitlab_api_token, 'token should be set'
         assert args.project_id, 'project id must be set'
@@ -87,10 +88,10 @@ class facile_trigger_helper(object):
 
         if robot_path:
             
-            facile_trigger = pyfiglet.figlet_format("facile.it Trigger Helper", font = "doom"  ) 
-            print(term.bold_cyan(facile_trigger))
-            print("Running robot path: " + robot_path)
-            print(color('gilab should be clored', fg='blue'))
+            facile_trigger = pyfiglet.figlet_format("facile.it Trigger Helper", font = "larry3d"  ) 
+            print(color(facile_trigger, fg='orange'))
+            print(color("Running robot path: " + robot_path, fg='green'))
+        
             self.trigger_pipeline(robot_path, git_lab_host, 
             api_gilab_token, target_branch, project_id)
 
@@ -100,7 +101,6 @@ class facile_trigger_helper(object):
         :project_id variable aims gitlab id found on project >> General:
         """
 
-        term = Terminal()
         git_trigger = gitlab.Gitlab(git_lab_host, private_token=api_gilab_token)
         project = git_trigger.projects.get(project_id)
         create_pipeline = project.pipelines.create({'ref': target_branch , 'variables': [{'key': 'RF_PATH', 'value': ref_name }]})
@@ -109,7 +109,7 @@ class facile_trigger_helper(object):
         pipe_jobs = pipeline.jobs.list()
         pipeline_jobs_count = len(pipe_jobs)
         pipeline_jobs_count = str(pipeline_jobs_count)
-        print(term.bold_cyan("Triggered pipeline holds " + pipeline_jobs_count + " jobs"))
+        print(color("Triggered pipeline holds " + pipeline_jobs_count + " jobs", fg='orange'))
         timeout = time.time() + 60 * 30
 
         while pipeline.finished_at is None:
@@ -117,22 +117,22 @@ class facile_trigger_helper(object):
             pipeline.refresh()
 
             if pipeline.status == "pending":
-                print(term.bright_yellow(project.name + " is " + pipeline.status))
+                print(color(project.name + " is " + pipeline.status, fg='yellow'))
             elif pipeline.status == "running":
-                print(term.bold_blue(project.name + " is " + pipeline.status))
+                print(color(project.name + " is " + pipeline.status, fg='blue'))
             if pipeline.status == "success":
-                print(term.bright_green(project.name + " is " + pipeline.status))
+                print(color(project.name + " is " + pipeline.status, fg='green'))
             elif pipeline.status == "failed":
-                print(term.bold_red(project.name + " is " + pipeline.status))
+                print(color(project.name + " is " + pipeline.status, fg='red'))
                 sys.exit(1)
             elif pipeline.status == "canceled":
-                print(term.bold_red(project.name + " is " + pipeline.status))
+                print(color(project.name + " is " + pipeline.status, fg='red'))
                 sys.exit(1)
             elif time.time() > timeout:
-                print(term.bright_red(project.name + " is " + pipeline.status))
+                print(color(project.name + " is " + pipeline.status, fg='red'))
                 sys.exit(1)
 
-            time.sleep(10)
+            time.sleep(2)
 
 def run_cli(arguments=None, exit=True):
        
@@ -143,7 +143,6 @@ def run_cli(arguments=None, exit=True):
     if arguments is None:
         arguments = sys.argv[1:]
     
-#    return facile_trigger_helper().main(sys.argv[1:])
     return facile_trigger_helper().main(arguments)
             
 if __name__ == '__main__':
